<?php
///////////////////////////////////////////////////////////////////////////

require_once 'lib/abstract_preloaded_regular_screen.php';

///////////////////////////////////////////////////////////////////////////

class GlobalTvTvSectionListScreen extends AbstractPreloadedRegularScreen
    implements UserInputHandler
{
    const ID = 'tv_section_list';

    ///////////////////////////////////////////////////////////////////////

    protected $tv;

    ///////////////////////////////////////////////////////////////////////

    public function __construct($tv, $folder_views)
    {
        parent::__construct(self::ID, $folder_views);
        $this->tv = $tv;
        UserInputHandlerRegistry::get_instance()->register_handler($this);
    }

    ///////////////////////////////////////////////////////////////////////

    public function get_handler_id()
    { return self::ID; }

    public function get_action_map(MediaURL $media_url, &$plugin_cookies)
    {
        $open_action =
            UserInputHandlerRegistry::create_action(
                $this, 'folder_open');
        $play_action =
            UserInputHandlerRegistry::create_action(
                $this, 'play_tv');

        return array
        (
            GUI_EVENT_KEY_ENTER => $open_action,// ActionFactory::open_folder(),
            GUI_EVENT_KEY_PLAY  => $play_action,// ActionFactory::tv_play(),
        );
    }

    ///////////////////////////////////////////////////////////////////////

    public function get_all_folder_items(MediaURL $media_url, &$plugin_cookies)
    {
        $this->tv->ensure_channels_loaded();
        $items = array();

        if (MainHelper::with_favorites())
        {
            $this->add_group_item($items,
                GlobalTvTvCategoryListScreen::get_media_url_str(SectionsHelper::FAV_SECTION_ID),
                T::todo('MY'), "plugin_file://icons/my.png");
        }

        $enabled_idset = SectionsHelper::get_enabled_sections_idset(true);
        $sections = $this->tv->get_sections();
        foreach ($sections as $id => $section)
        {
            if (!isset($enabled_idset[$id]))
                continue;

            $small_icon_url = SectionsHelper::section_get_icon_url($section);

            $this->add_group_item($items,
                GlobalTvTvCategoryListScreen::get_media_url_str($section['id']),
                $section['name'], $small_icon_url);
        }

        return $items;
    }

    private function add_group_item(&$items, $media_url, $name, $icon_url)
    {
        $items[] = array(
            PluginRegularFolderItem::media_url => $media_url,
            PluginRegularFolderItem::caption => $name,
            PluginRegularFolderItem::view_item_params => array(
                ViewItemParams::icon_path => $icon_url,
                ViewItemParams::item_detailed_icon_path => $icon_url,
            )
        );
    }

    public function get_archive(MediaURL $media_url)
    {
        return $this->tv->get_archive($media_url);
    }

    private function show_enter_parental_code_dialog($control_id)
    {
        $defs = array();
        $tparams = array('fixed_osk_id' => 'numeric');
        ControlFactory::add_text_field($defs, $this, null,
            'protect_code', T::g('dune_tv_label_protect_code'), '',
            true, false, false, true, 500, false, false, $tparams);

        ControlFactory::add_vgap($defs, 10);

        $post_action = UserInputHandlerRegistry::create_action($this, $control_id);
        ControlFactory::add_custom_close_dialog_and_apply_button($defs,
            'ok', T::g('button_ok'), 300, $post_action);
        ControlFactory::add_custom_close_dialog_and_apply_button($defs,
            'cancel', T::g('button_cancel'), 300, null);

        return ActionFactory::show_dialog(T::g('title_enter_parental_code'), $defs, false, 0);
    }

    private function show_enter_parental_code_dialog_if_needed($user_input, $section_id)
    {
        $code_is_needed = ($section_id == 'xxx') &&
            (MainHelper::read_xxx_password() != '') &&
            HD::with_builtin_pcontrol();

        if (!$code_is_needed)
            return true;

        $control_id = HD::get($user_input, 'control_id');
        $protect_code = HD::get($user_input, 'protect_code', null);

        if ($protect_code === null)
            return $this->show_enter_parental_code_dialog($control_id);
        else if ($protect_code != MainHelper::read_xxx_password())
            return ActionFactory::show_title_dialog(T::g('wrong_parental_code'));

        return true;
    }

    public function handle_user_input(&$user_input, &$plugin_cookies)
    {
        hd_print('TV section list: handle_user_input:');
        foreach ($user_input as $key => $value)
            hd_print("  $key => $value");

        $section_id = null;
        if (isset($user_input->selected_media_url))
        {
            $media_url = MediaURL::decode($user_input->selected_media_url);
            $section_id = $media_url->section_id;
        }

        $action = MainHelper::get_pf_check_action_if_needed($user_input, "TV section list", false);
        if ($action != null)
            return $action;

        $group_ids = $this->tv->get_group_ids_by_section_id($section_id, $plugin_cookies);
        $group_id = isset($group_ids[0]) ? $group_ids[0] : '18';

        $a = MainHelper::get_pre_playback_action_for_group_if_needed($this, $group_id, $user_input, $plugin_cookies);
        if ($a !== true)
            return $a;

        $a = $this->show_enter_parental_code_dialog_if_needed($user_input, $section_id);
        if ($a !== true)
            return $a;

        $control_id = HD::get($user_input, 'control_id');
        if ($control_id == 'folder_open')
            return ActionFactory::open_folder();
        else if ($control_id == 'play_tv')
            return ActionFactory::tv_play();

        return null;
    }
}

///////////////////////////////////////////////////////////////////////////
?>
