#!/usr/bin/php
<?php

function hd_print($x) {
    fwrite(STDERR, "$x\n");
}

function hd_get($map, $key, $def=null)
{
    if (!isset($map) || !isset($key))
        return $def;
    if (is_object($map))
        return isset($map->$key) ? $map->$key : $def;
    if (is_array($map))
        return isset($map[$key]) ? $map[$key] : $def;
    return $def;
}

if (count($argv) != 2)
{
    hd_print("Usage: json2plain.php input_file");
    exit(1);
}

$path = $argv[1];
if (!is_file($path))
{
    hd_print("Usage: input file not found");
    exit(1);
}

$doc = file_get_contents($path);
$obj = json_decode($doc);
if (!$obj || !isset($obj->categories) || !isset($obj->channels))
{
    hd_print("Usage: incorrect input file");
    exit(1);
}

$cat_by_id = array();
foreach ($obj->categories as $cat)
    $cat_by_id[$cat->id] = $cat;

$ICON_PREFIX = "https://lo1.in/LOGO/";
$IP_LEN = strlen($ICON_PREFIX);

$channel_ids = array();
$channel_by_id = array();
foreach ($obj->channels as $ch) {
    $id = (int) hd_get($ch, 'id');
    $name = hd_get($ch, 'name');
    $icon_url = hd_get($ch, 'icon_url', '');
    $stream_id = (int) hd_get($ch, 'stream_id');
    $epg_id = hd_get($ch, 'epg_id', '');
    $archive_days = (int) hd_get($ch, 'archive_days', 0);

    if (!$id || !$name || !$stream_id)
        continue;

    if (0 === strpos($icon_url, 'data:image'))
        $icon_url = '';

    if (!$icon_url ||
        (0 !== strpos($icon_url, 'https://')) &&
        (0 !== strpos($icon_url, 'http://')))
    {
        $icon_url = '';
    }
    else if (0 === strpos($icon_url, $ICON_PREFIX))
        $icon_url = substr($icon_url, $IP_LEN);

    $channel_ids[] = $id;

    $arr = array(
        'id' => $id,
        'name' => $name,
        'icon_url' => $icon_url,
        'stream_id' => $stream_id);
    if ($epg_id)
        $arr['epg_id'] = $epg_id;
    if ($archive_days > 0)
        $arr['archive_days'] = $archive_days;
    $channel_by_id[$ch->id] = (object) $arr;
}

$res = array(
    'icon_prefix' => $ICON_PREFIX,
    'categories' => $cat_by_id,
    'channels' => $channel_by_id,
    'channel_ids' => $channel_ids);

$doc = json_encode($res, JSON_UNESCAPED_SLASHES | JSON_UNESCAPED_UNICODE);
echo($doc);

?>
