<?php

class ListHelper implements UserInputHandler
{
    public function __construct()
    {
        UserInputHandlerRegistry::get_instance()->register_handler($this);
    }

    public function get_handler_id()
    {
        return 'list_helper';
    }

    public function custom_action($control_id, $params=null)
    {
        return UserInputHandlerRegistry::create_action(
            $this, $control_id, $params);
    }

    private function add_gui_item(&$all_items, &$def_ids,
        $id, $caption, $icon_url, $group_id)
    {
        $def_ids[] = $id;
        ActionFactory::add_gui_item($all_items,
            $id, $caption, $icon_url, $group_id);
    }

    private static function cat_name_to_lcfg_gid($name)
    {
        $pos = strpos($name, '|');
        $gid = $pos ? trim(substr($name, 0, $pos)) : '';
        return $gid ? $gid : null;
    }

    public function edit_cats_list($section_id)
    {
        $plugin_cookies = MainHelper::$plugin->get_plugin_cookies();

        $cache = MainHelper::$cache;
        $cache->ensure_cache_loaded();

        $tv = MainHelper::$tv;
        $tv->ensure_channels_loaded();
        $section_by_id = $tv->get_sections();
        $group_by_id = $tv->get_groups();

        $is_fav = $section_id == 'fav' ||
            $section_id == SectionsHelper::FAV_SECTION_ID;
        $section = $is_fav ? null : HD::get($section_by_id, $section_id);

        if ($section) {
            $group_ids = $section['categories'];
        } else if ($is_fav) {
            $group_ids = $tv->get_fav_category_ids($plugin_cookies);
        } else {
            hd_print("list E: section not found: '$section_id'");
            return null;
        }

        $lcfg_groups = array();
        $lcfg_gidmap = array();
        $other_count = 0;

        $all_items = array();
        $def_ids = array();

        foreach ($group_ids as $gid)
        {
            $g = HD::get($group_by_id, $gid);
            if (!$g)
                continue;
            if (!HD::get($g, 'show_on_rows_screen', 1))
                continue;

            $id = $g['id'];
            $name = $g['name'];

            $lcfg_gid = self::cat_name_to_lcfg_gid($name);
            if ($lcfg_gid && !isset($lcfg_gidmap[$lcfg_gid])) {
                $lcfg_gidmap[$lcfg_gid] = 1;
            } else if ($lcfg_gid) {
                $lcfg_gidmap[$lcfg_gid]++;
            } else {
                $other_count++;
                $lcfg_gid = 'other';
            }

            $this->add_gui_item($all_items, $def_ids,
                $id, $name, null, $lcfg_gid);
        }

        if ($other_count)
            $lcfg_gidmap['other'] = $other_count;
        foreach ($lcfg_gidmap as $lcfg_gid => $n)
        {
            $caption = $lcfg_gid == 'other' ?
                T::ti('other_categories') : $lcfg_gid;
            $caption = T::t2('group_with_count__2', $caption, $n);
            ActionFactory::add_gui_item($lcfg_groups, $lcfg_gid,
                $caption, null, null);
        }

        $lcfg = ConfigHolder::cats_lcfg_ensure_loaded($section_id);
        
        $a = $this->custom_action('apply_list_config');

        $options = $is_fav ?
            EDIT_LIST_CONFIG_OPT_REMOVE_UNCHECKED : 0;

        $config_id = ConfigHolder::cats_config_id($section_id);
        return ActionFactory::edit_list_config(
            $config_id, T::g('configure_list_title'),
            $all_items, $def_ids, $lcfg_groups, $options, $a);
    }

    private function apply_edit_section_categories($user_input,
        $lcfg_id, $to_remove)
    {
        $section_id = ConfigHolder::get_section_id_from_config_id($lcfg_id);
        hd_print("list D: applying for section $section_id");

        if ($to_remove)
        {
            $plugin_cookies = MainHelper::$plugin->get_plugin_cookies();
            $fav_op_type = PLUGIN_FAVORITES_OP_REMOVE;
            foreach ($to_remove as $category_id)
            {
                hd_print("list D: removing $category_id from favorites");
                MainHelper::$tv->change_tv_favorites_categories(
                    $fav_op_type, $category_id, $plugin_cookies);
            }
        }

        ConfigHolder::cats_lcfg_reload($section_id);

        $eff_section_id = $section_id == 'fav' ?
            SectionsHelper::FAV_SECTION_ID : $section_id;
        EpfsHandler::force_update_section($eff_section_id);

        return ActionFactory::reread_all_epfs(false);
    }

    public function handle_user_input(&$user_input, &$plugin_cookies)
    {
        $control_id = HD::get($user_input, 'control_id');

        hd_print('ListHelper: handle_user_input:');
        foreach ($user_input as $k => $v) {
            $len = strlen($v);
            if ($len > 1024)
                $v = substr($v, 0, 1024) . "... (" . ($len - 1024) . " more)";
            hd_print("  $k => $v");
        }

        if ($control_id == 'apply_list_config')
        {
            $config_changed = HD::get($user_input, 'list_config_changed');
            $config_id = HD::get($user_input, 'list_config_id');

            if (!$config_changed)
            {
                hd_print("edit list I: config not changed: $config_id");
                return null;
            }

            $to_remove = HD::get($user_input, 'list_config_to_remove');
            if ($to_remove)
                $to_remove = json_decode($to_remove, 1);

            return $this->apply_edit_section_categories(
                $user_input, $config_id, $to_remove);
        }

        return null;
    }

}

?>
