<?php

class SectionsHelper
{
    const SECTIONS_ON_OFF_FILE = 'sections_on_off.txt';

    const FAV_SECTION_ID = -9;

    private static $country_code_by_lang_code = array(
        "ar" => "AE",
        "az" => "AZ",
        "bg" => "BG",
        "bn" => "BD",
        "bs" => "BA",
        "cs" => "CZ",
        "da" => "DK",
        "de" => "DE",
        "el" => "GR",
        "en" => "GB",
        "en_US" => "US",
        "es" => "ES",
        "fa" => "IR",
        "fi" => "FI",
        "fil" => "PH",
        "fr" => "FR",
        "he" => "IL",
        "hi" => "IN",
        "hr" => "HR",
        "hu" => "HU",
        "hy" => "AM",
        "id" => "ID",
        "is" => "IS",
        "it" => "IT",
        "ja" => "JP",
        "ka" => "GE",
        "kk" => "KZ",
        "km" => "KH",
        "ko" => "KR",
        "ku" => "IQ",
        "lt" => "LT",
        "mk" => "MK",
        "ms" => "MY",
        "mt" => "MT",
        "nl" => "NL",
        "no" => "NO",
        "pl" => "PL",
        "ps" => "AF",
        "pt" => "PT",
        "ro" => "RO",
        "ru" => "RU",
        "sh" => "RS",
        "si" => "LK",
        "sk" => "SK",
        "sl" => "SI",
        "sq" => "AL",
        "sr" => "RS",
        "sv" => "SE",
        "th" => "TH",
        "tr" => "TR",
        "uk" => "UA",
        "ur" => "PK",
        "vi" => "VN",
        "zh" => "CN",
    );

    public static function section_get_icon_url($section)
    {
        $country_code = "";
        if (isset($section['country_codes']) &&
            count($section['country_codes']) == 1)
        {
            $ccode = $section['country_codes'][0];
            if (is_file("/firmware/skin/flags/${ccode}.png"))
                $country_code = $ccode;
        }

        $token = "";
        if (isset($section['token']))
            $token = $section['token'];

        if ($country_code == '' && $token == '' && isset($section['lang_codes']))
        {
            $lang_codes = $section['lang_codes'];
            if (count($lang_codes) > 0)
            {
                $lang_code = $lang_codes[0];
                if (isset(self::$country_code_by_lang_code[$lang_code]))
                    $country_code = self::$country_code_by_lang_code[$lang_code];
            }
        }

        $pname = MainHelper::$plugin_name;
        $base_small_icon_url = "plugin_file://%$pname%/icons";
        if ($country_code != '')
            return "/firmware/skin/flags/${country_code}.png";
        if ($token != '')
            return "$base_small_icon_url/${token}.png";
        return "$base_small_icon_url/all.png";
    }

    public static function get_sections_on_off_path()
    {
        return DuneSystem::$properties['data_dir_path'] .
            '/' . self::SECTIONS_ON_OFF_FILE;
    }

    public static function get_enabled_sections_idset($avoid_empty)
    {
        $cache = MainHelper::$cache;
        $all_ids = array_keys($cache->get_section_by_id_map());

        $def_ids = $cache->get_def_section_ids();

        $path = self::get_sections_on_off_path();
        $on_off = ListUtils::read_on_off_file($path);
        return ListUtils::get_enabled_idset_from_on_off(
            $all_ids, $def_ids, $on_off, $avoid_empty);
    }
}


?>
