<?php

require_once 'lib/lang.php';
include_once 'dunelib/dune_countries.php';

class SystemConfig
{
    private static $instance = null;

    public static function get_instance()
    {
        if (!isset(self::$instance))
            self::$instance = new SystemConfig();
        return self::$instance;
    }

    private function __construct()
    { }

    ///////////////////////////////////////////////////////////////////////

    public $all;
    public $lang_code;
    public $widget_country;
    public $country_code_uc;

    private static function load_config()
    {
        $cfg = (object) array(
            'interface_language' => 'english',
            'noncustom_interface_language' => 'english',
            'widget_country' => '',
        );

        $lines = file("/config/settings.properties",
            FILE_IGNORE_NEW_LINES | FILE_SKIP_EMPTY_LINES);
        foreach ($lines as $line)
        {
            $pos = strpos($line, " = ");
            if ($pos === false)
                continue;

            $key = trim(substr($line, 0, $pos));
            if (isset($cfg->$key))
                $cfg->$key = trim(substr($line, $pos + 3));
        }

        if ($cfg->interface_language == 'custom')
            $cfg->interface_language = $cfg->noncustom_interface_language;

        $cfg->lang_code = Lang::get_code_by_id($cfg->interface_language);
        if (!isset($cfg->lang_code)) // should not happen
        {
            hd_print("Warning: unknown language: '$cfg->interface_language'");
            $cfg->interface_language = "english";
            $cfg->lang_code = "en";
        }

        return $cfg;
    }

    private function reload_settings()
    {
        $this->all = self::load_config();
        $this->lang_code = $this->all->lang_code;
        $this->widget_country =
            mb_strtolower($this->all->widget_country, "UTF-8");

        hd_print("Interface language: $this->lang_code");
        hd_print("Widget country: $this->widget_country");
    }

    private function reload_location_info()
    {
        $this->country_code_uc = "";

        if (is_file("/tmp/location_info.properties"))
            $location_info_path = "/tmp/location_info.properties";
        else if (is_file("/config/location_info.properties"))
            $location_info_path = "/config/location_info.properties";
        else
            return;

        $lines = file($location_info_path,
            FILE_IGNORE_NEW_LINES | FILE_SKIP_EMPTY_LINES);
        foreach ($lines as $line)
        {
            if (preg_match('/^country_code_2 =\s*(\S\S)\s*$/', $line, $matches))
                $this->country_code_uc = mb_strtoupper($matches[1], "UTF-8");
        }

        if (strlen($this->widget_country) == 2)
            $this->country_code_uc = mb_strtoupper($this->widget_country, "UTF-8");
        else if ($this->widget_country != '')
        {
            try
            {
                $code = DuneCountries::get_code_by_name($this->widget_country);
            }
            catch (Exception $e)
            {
                $code = "";
            }
            $this->country_code_uc = $code ? $code : "WW";
        }

        hd_print("Country code: " . $this->country_code_uc);
    }

    public function reload()
    {
        $this->reload_settings();
        $this->reload_location_info();
    }

    public function ensure_loaded()
    {
        if (isset($this->lang_code))
            return;

        $this->reload();
    }
}

?>
